==> owncloud-8.1.9.tar.bz2: owncloud/settings/l10n/bs.js <==
OC.L10N.register(
    "settings",
    {
    "Sharing" : "Dijeljenje",
    "Cron" : "Cron",
    "Log" : "Zapisnik",
    "Updates" : "Ažuriranja",
    "Authentication error" : "Grešna autentifikacije",
    "Your full name has been changed." : "Vaše puno ime je promijenjeno.",
    "Unable to change full name" : "Puno ime nije moguće promijeniti",
    "Couldn't remove app." : "Nije moguće ukloniti aplikaciju.",
    "Language changed" : "Jezik je promijenjen",
    "Invalid request" : "Neispravan zahtjev",
    "Admins can't remove themself from the admin group" : "Administratori ne mogu sami sebe ukloniti iz admin grupe",
    "Unable to add user to group %s" : "Dodavanje korisnika grupi %s nije moguće",
    "Unable to remove user from group %s" : "Uklanjanje korisnika iz grupe %s nije moguće",
    "Couldn't update app." : "Ažuriranje aplikacije nije moguće.",
    "Wrong password" : "Pogrešna lozinka",
    "No user supplied" : "Nijedan korisnik nije dostavljen",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Molim navedite admin lozinku za povratak, u protivnom će svi korisnički podaci biti izgubljeni",
    "Wrong admin recovery password. Please check the password and try again." : "Pogrešna admin lozinka za povratak. Molim provjerite lozinku i pokušajte ponovno.",
    "Unable to change password" : "Promjena lozinke nije moguća",
    "Enabled" : "Aktivirano",
    "Not enabled" : "Nije aktivirano",
    "Group already exists." : "Grupa već postoji.",
    "Unable to add group." : "Nemoguće dodati grupu.",
    "Unable to delete group." : "Nemoguće izbrisati grupu.",
    "Saved" : "Spremljeno",
    "test email settings" : "testiraj postavke e-pošte",
    "Email sent" : "E-pošta je poslana",
    "You need to set your user email before being able to send test emails." : "Prije nego li ste u mogućnosti slati testnu email trebate postaviti svoj korisnički email.",
    "Invalid mail address" : "Nevažeća adresa e-pošte",
    "Unable to create user." : "Nemoguće kreirati korisnika",
    "Your %s account was created" : "Vaš %s račun je kreiran",
    "Unable to delete user." : "Nemoguće izbrisati korisnika",
    "Forbidden" : "Zabranjeno",
    "Invalid user" : "Nevažeči korisnik",
    "Unable to change mail address" : "Nemoguće je izmjeniti adresu e-pošte",
    "Email saved" : "E-pošta je spremljena",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Jeste li zaista sigurni da želite dodati \"{domain}\" kao pouzdanu domenu?",
    "Add trusted domain" : "Dodaj pouzdanu domenu",
    "Sending..." : "Slanje...",
    "All" : "Sve",
    "Update to %s" : "Ažuriraj na %s",
    "Please wait...." : "Molim pričekajte...",
    "Error while disabling app" : "Greška pri onemogućavanju aplikacije",
    "Disable" : "Onemogući",
    "Enable" : "Omogući",
    "Error while enabling app" : "Greška pri omogućavanju aplikacije",
    "Updating...." : "Ažuriranje...",
    "Error while updating app" : "Greška pri ažuriranju aplikacije",
    "Updated" : "Ažurirano",
    "Uninstalling ...." : "Deinstaliranje....",
    "Error while uninstalling app" : "Greška pri deinstaliranju aplikacije",
    "Uninstall" : "Deinstaliraj",
    "Select a profile picture" : "Odaberi sliku profila",
    "Very weak password" : "Veoma slaba lozinka",
    "Weak password" : "Slaba lozinka",
    "So-so password" : "Tu-i-tamo lozinka",
    "Good password" : "Dobra lozinka",
    "Strong password" : "Jaka lozinka",
    "Valid until {date}" : "Validno do {date}",
    "Delete" : "Izbriši",
    "Groups" : "Grupe",
    "Unable to delete {objName}" : "Nije moguće izbrisati {objName}",
    "Error creating group" : "Greška pri kreiranju grupe",
    "A valid group name must be provided" : "Nužno je navesti valjani naziv grupe",
    "deleted {groupName}" : "izbrisana {groupName}",
    "undo" : "poništi",
    "no group" : "nema grupe",
    "never" : "nikad",
    "deleted {userName}" : "izbrisan {userName}",
    "add group" : "dodaj grupu",
    "A valid username must be provided" : "Nužno je navesti valjano korisničko ime",
    "Error creating user" : "Greška pri kreiranju korisnika",
    "A valid password must be provided" : "Nužno je navesti valjanu lozinku",
    "A valid email must be provided" : "Nužno je navesti valjanu adresu e-pošte",
    "__language_name__" : "__naziv_jezika___",
    "SSL root certificates" : "SSL root certifikati",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Sve (fatalni problemi, greške, upozorenja, info, ispravljanje pogrešaka)",
    "Info, warnings, errors and fatal issues" : "Informacije, upozorenja, greške i fatalni problemi",
    "Warnings, errors and fatal issues" : "Upozorenja, greške i fatalni problemi",
    "Errors and fatal issues" : "Greške i fatalni problemi",
    "Fatal issues only" : "Samo fatalni problemi",
    "None" : "Ništa",
    "Login" : "Prijava",
    "Plain" : "Čisti tekst",
    "NT LAN Manager" : "NT LAN menedžer",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Samo-čitajuća konfiguracija je podešena. Ovo spriječava postavljanje neke konfiguracije putem web-sučelja. Nadalje, datoteka mora biti omogućena ručnu izmjenu pri svakom ažuriranju.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je očigledno postavljen da se skine inline doc blokova. To će nekoliko osnovnih aplikacija učiniti nedostupnim.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Uzrok tome je vjerojatno neki ubrzivač predmemorisanja kao što je Zend OPcache ili eAccelerator.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP modul 'fileinfo' nedostaje. Strogo vam preporučjem da taj modul omogućite kako biste dobili najbolje rezultate u detekciji mime vrste.",
    "System locale can not be set to a one which supports UTF-8." : "Regionalnu šemu sustava nemoguće je postaviti na neku koja podržava UTF-8.",
    "This means that there might be problems with certain characters in file names." : "To znači da se mogu javiti problemi s određenim znakovima u nazivu datoteke.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Strogo se preporučuje instaliranje zahtjevnih paketa na vašem sistemu koji podržavaju jednu od slijedećih regionalnih šemi: %s.",
    "Allow apps to use the Share API" : "Dozvoli aplikacijama korištenje Share API",
    "Allow users to share via link" : "Dozvoli korisnicima dijeljenje putem veze",
    "Enforce password protection" : "Nametni zaštitu lozinke",
    "Allow public uploads" : "Dozvoli javno učitavanje",
    "Allow users to send mail notification for shared files" : "Dozvoli korisnicima slanje notifikacijske e-pošte za podijeljene datoteke",
    "Set default expiration date" : "Postavite zadani datum isteka",
    "Expire after " : "Istek nakon",
    "days" : "dana",
    "Enforce expiration date" : "Nametni datum isteka",
    "Allow resharing" : "Dopustite ponovno dijeljenje",
    "Restrict users to only share with users in their groups" : "Ograniči korisnike na međusobno dijeljenje resursa samo s korisnicima unutar svoje grupe",
    "Allow users to send mail notification for shared files to other users" : "Dozvoli korisnicima slanje notifikacijske e-pošte za podijeljene datoteke ka ostalim korisnicima",
    "Exclude groups from sharing" : "Isključite grupe iz dijeljenja",
    "These groups will still be able to receive shares, but not to initiate them." : "Ove će grupe i dalje moći primati dijeljene resurse, ali ne i inicirati ih",
    "Cron was not executed yet!" : "Cron još nije izvršen!",
    "Execute one task with each page loaded" : "Izvrši jedan zadatak sa svakom učitanom stranicom",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php je registrovan na webcron usluzi da poziva cron.php svakih 15 minuta preko http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Koristite cron uslugu sustava za pozivanje cron.php datoteke svakih 15 minuta.",
    "This is used for sending out notifications." : "Ovo se koristi za slanje notifikacija.",
    "Send mode" : "Način rada za slanje",
    "Encryption" : "Šifriranje",
    "From address" : "S adrese",
    "mail" : "pošta",
    "Authentication method" : "Metoda autentifikacije",
    "Authentication required" : "Potrebna autentifikacija",
    "Server address" : "Adresa servera",
    "Port" : "Priključak",
    "Credentials" : "Vjerodajnice",
    "SMTP Username" : "SMTP Korisničko ime",
    "SMTP Password" : "SMPT Lozinka",
    "Store credentials" : "Spremi vjerodajnice",
    "Test email settings" : "Postavke za testnu e-poštu",
    "Send email" : "Pošalji e-poštu",
    "Log level" : "Razina zapisnika",
    "More" : "Više",
    "Less" : "Manje",
    "Version" : "Verzija",
    "by" : "od strane",
    "licensed" : "licenciran",
    "Documentation:" : "Dokumentacija:",
    "User Documentation" : "Korisnička Dokumentacija",
    "Admin Documentation" : "Admin Dokumentacija",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ova aplikacija se ne može instalirati zbog slijedećih neispunjenih ovisnosti:",
    "Enable only for specific groups" : "Omogućite samo za specifične grupe",
    "Uninstall App" : "Deinstaliraj aplikaciju",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hej,<br><br>samo da javim da sad imate %s račum.<br><br>Vaše korisničko ime: %s<br>Pristupite mu: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Cheers!",
    "Forum" : "Forum",
    "Get the apps to sync your files" : "Koristite aplikacije za sinhronizaciju svojih datoteka",
    "Desktop client" : "Desktop klijent",
    "Android app" : "Android aplikacija",
    "iOS app" : "iOS aplikacija",
    "Show First Run Wizard again" : "Opet pokažite First Run Wizard",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Iskoristili ste <strong>%s</strong> od raspoloživog <strong>%s</strong>",
    "Password" : "Lozinka",
    "Unable to change your password" : "Vašu lozinku nije moguće promijeniti",
    "Current password" : "Trenutna lozinka",
    "New password" : "Nova lozinka",
    "Change password" : "Promijeni lozinku",
    "Email" : "E-pošta",
    "Your email address" : "Vaša adresa e-pošte",
    "Fill in an email address to enable password recovery and receive notifications" : "Unesite adresu e-pošte da biste omogućili oporavak lozinke i primili notifikacije",
    "Profile picture" : "Slika profila",
    "Upload new" : "Učitaj novu",
    "Select new from Files" : "Odaberi novu iz datoteka",
    "Remove image" : "Ukloni sliku",
    "Either png or jpg. Ideally square but you will be able to crop it." : "Ili png ili jpg. Idealno bi bilo da je kvadratna, ali moći ćete je obrezati",
    "Your avatar is provided by your original account." : "Vaš avatar je isporučen od strane vašeg izvornog računa.",
    "Cancel" : "Odustani",
    "Choose as profile image" : "Izaberi kao sliku profila",
    "Language" : "Jezik",
    "Help translate" : "Pomozi prevesti",
    "Common Name" : "Opće Ime",
    "Valid until" : "Validno do",
    "Issued By" : "Izdano od",
    "Valid until %s" : "Validno do %s",
    "Show storage location" : "Prikaži mjesto pohrane",
    "Show last log in" : "Prikaži zadnju prijavu",
    "Show user backend" : "Prikaži korisničku pozadinu (backend)",
    "Send email to new user" : "Pošalji e-poštu novom korisniku",
    "Show email address" : "Prikaži adresu e-pošte",
    "Username" : "Korisničko ime",
    "E-Mail" : "E-pošta",
    "Create" : "Kreiraj",
    "Admin Recovery Password" : "Admin lozinka za oporavak",
    "Enter the recovery password in order to recover the users files during password change" : "Unesite lozinku za oporavak da biste oporavili korisničke datoteke tokom promjene lozinke",
    "Search Users" : "Traži Korisnike",
    "Add Group" : "Dodaj Grupu",
    "Group" : "Grupa",
    "Everyone" : "Svi",
    "Admins" : "Administratori",
    "Default Quota" : "Zadana kvota",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Molim unesite kvotu za spremanje (npr: \"512 MB\" ili \"12 GB\")",
    "Unlimited" : "Neograničeno",
    "Other" : "Ostali",
    "Full Name" : "Puno ime",
    "Group Admin for" : "Grupa Admin za",
    "Quota" : "Kvota",
    "Storage Location" : "Mjesto za spremanje",
    "User Backend" : "Korisnička Pozadina (Backend)",
    "Last Login" : "Zadnja prijava",
    "change full name" : "promijeni puno ime",
    "set new password" : "postavi novu lozinku",
    "change email address" : "promjeni adresu e-pošte",
    "Default" : "Zadano"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-10.7.0.tar.bz2: owncloud/settings/l10n/bs.js <==
OC.L10N.register(
    "settings",
    {
    "No user supplied" : "Nijedan korisnik nije dostavljen",
    "Authentication error" : "Grešna autentifikacije",
    "Wrong admin recovery password. Please check the password and try again." : "Pogrešna admin lozinka za povratak. Molim provjerite lozinku i pokušajte ponovno.",
    "Unable to change password" : "Promjena lozinke nije moguća",
    "Couldn't send reset email. Please contact your administrator." : "Slanje emaila resetovanja nije moguće. Molim kontaktirajte administratora.",
    "Group already exists." : "Grupa već postoji.",
    "Unable to add group." : "Nemoguće dodati grupu.",
    "Unable to delete group." : "Nemoguće izbrisati grupu.",
    "Saved" : "Spremljeno",
    "test email settings" : "testiraj postavke e-pošte",
    "Email sent" : "E-pošta je poslana",
    "You need to set your user email before being able to send test emails." : "Prije nego li ste u mogućnosti slati testnu email trebate postaviti svoj korisnički email.",
    "Your %s account was created" : "Vaš %s račun je kreiran",
    "Invalid mail address" : "Nevažeća adresa e-pošte",
    "Unable to create user." : "Nemoguće kreirati korisnika",
    "Unable to delete user." : "Nemoguće izbrisati korisnika",
    "Forbidden" : "Zabranjeno",
    "Invalid user" : "Nevažeči korisnik",
    "Unable to change mail address" : "Nemoguće je izmjeniti adresu e-pošte",
    "Your full name has been changed." : "Vaše puno ime je promijenjeno.",
    "Unable to change full name" : "Puno ime nije moguće promijeniti",
    "Create" : "Kreiraj",
    "Delete" : "Izbriši",
    "Share" : "Dijeli",
    "Language changed" : "Jezik je promijenjen",
    "Invalid request" : "Neispravan zahtjev",
    "Admins can't remove themself from the admin group" : "Administratori ne mogu sami sebe ukloniti iz admin grupe",
    "Couldn't remove app." : "Nije moguće ukloniti aplikaciju.",
    "All" : "Sve",
    "Enabled" : "Aktivirano",
    "Not enabled" : "Nije aktivirano",
    "Please wait...." : "Molim pričekajte...",
    "Error while disabling app" : "Greška pri onemogućavanju aplikacije",
    "Disable" : "Onemogući",
    "Enable" : "Omogući",
    "Error while enabling app" : "Greška pri omogućavanju aplikacije",
    "Updating...." : "Ažuriranje...",
    "Error while updating app" : "Greška pri ažuriranju aplikacije",
    "Updated" : "Ažurirano",
    "Uninstalling ...." : "Deinstaliranje....",
    "Error while uninstalling app" : "Greška pri deinstaliranju aplikacije",
    "Uninstall" : "Deinstaliraj",
    "Valid until {date}" : "Validno do {date}",
    "Sending..." : "Slanje...",
    "Select a profile picture" : "Odaberi sliku profila",
    "Very weak password" : "Veoma slaba lozinka",
    "Weak password" : "Slaba lozinka",
    "So-so password" : "Tu-i-tamo lozinka",
    "Good password" : "Dobra lozinka",
    "Strong password" : "Jaka lozinka",
    "Groups" : "Grupe",
    "Unable to delete {objName}" : "Nije moguće izbrisati {objName}",
    "A valid group name must be provided" : "Nužno je navesti valjani naziv grupe",
    "deleted {groupName}" : "izbrisana {groupName}",
    "undo" : "poništi",
    "never" : "nikad",
    "deleted {userName}" : "izbrisan {userName}",
    "add group" : "dodaj grupu",
    "no group" : "nema grupe",
    "A valid username must be provided" : "Nužno je navesti valjano korisničko ime",
    "A valid password must be provided" : "Nužno je navesti valjanu lozinku",
    "A valid email must be provided" : "Nužno je navesti valjanu adresu e-pošte",
    "Cheers!" : "Cheers!",
    "Language" : "Jezik",
    "Documentation:" : "Dokumentacija:",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ova aplikacija se ne može instalirati zbog slijedećih neispunjenih ovisnosti:",
    "Enable only for specific groups" : "Omogućite samo za specifične grupe",
    "Uninstall App" : "Deinstaliraj aplikaciju",
    "Cron" : "Cron",
    "Cron was not executed yet!" : "Cron još nije izvršen!",
    "Execute one task with each page loaded" : "Izvrši jedan zadatak sa svakom učitanom stranicom",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php je registrovan na webcron usluzi da poziva cron.php svakih 15 minuta preko http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Koristite cron uslugu sustava za pozivanje cron.php datoteke svakih 15 minuta.",
    "Common Name" : "Opće Ime",
    "Valid until" : "Validno do",
    "Issued By" : "Izdano od",
    "Valid until %s" : "Validno do %s",
    "Sharing" : "Dijeljenje",
    "Allow apps to use the Share API" : "Dozvoli aplikacijama korištenje Share API",
    "Allow users to share via link" : "Dozvoli korisnicima dijeljenje putem veze",
    "Allow public uploads" : "Dozvoli javno učitavanje",
    "Set default expiration date" : "Postavite zadani datum isteka",
    "Expire after " : "Istek nakon",
    "days" : "dana",
    "Allow users to send mail notification for shared files" : "Dozvoli korisnicima slanje notifikacijske e-pošte za podijeljene datoteke",
    "Allow resharing" : "Dopustite ponovno dijeljenje",
    "Restrict users to only share with users in their groups" : "Ograniči korisnike na međusobno dijeljenje resursa samo s korisnicima unutar svoje grupe",
    "Allow users to send mail notification for shared files to other users" : "Dozvoli korisnicima slanje notifikacijske e-pošte za podijeljene datoteke ka ostalim korisnicima",
    "Exclude groups from sharing" : "Isključite grupe iz dijeljenja",
    "These groups will still be able to receive shares, but not to initiate them." : "Ove će grupe i dalje moći primati dijeljene resurse, ali ne i inicirati ih",
    "None" : "Ništa",
    "Save" : "Spremi",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Sve (fatalni problemi, greške, upozorenja, info, ispravljanje pogrešaka)",
    "Info, warnings, errors and fatal issues" : "Informacije, upozorenja, greške i fatalni problemi",
    "Warnings, errors and fatal issues" : "Upozorenja, greške i fatalni problemi",
    "Errors and fatal issues" : "Greške i fatalni problemi",
    "Fatal issues only" : "Samo fatalni problemi",
    "Log" : "Zapisnik",
    "Login" : "Prijava",
    "Plain" : "Čisti tekst",
    "NT LAN Manager" : "NT LAN menedžer",
    "This is used for sending out notifications." : "Ovo se koristi za slanje notifikacija.",
    "Send mode" : "Način rada za slanje",
    "Encryption" : "Šifriranje",
    "From address" : "S adrese",
    "mail" : "pošta",
    "Authentication method" : "Metoda autentifikacije",
    "Authentication required" : "Potrebna autentifikacija",
    "Server address" : "Adresa servera",
    "Port" : "Priključak",
    "Credentials" : "Vjerodajnice",
    "SMTP Username" : "SMTP Korisničko ime",
    "SMTP Password" : "SMPT Lozinka",
    "Store credentials" : "Spremi vjerodajnice",
    "Test email settings" : "Postavke za testnu e-poštu",
    "Send email" : "Pošalji e-poštu",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Samo-čitajuća konfiguracija je podešena. Ovo spriječava postavljanje neke konfiguracije putem web-sučelja. Nadalje, datoteka mora biti omogućena ručnu izmjenu pri svakom ažuriranju.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je očigledno postavljen da se skine inline doc blokova. To će nekoliko osnovnih aplikacija učiniti nedostupnim.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Uzrok tome je vjerojatno neki ubrzivač predmemorisanja kao što je Zend OPcache ili eAccelerator.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP modul 'fileinfo' nedostaje. Strogo vam preporučjem da taj modul omogućite kako biste dobili najbolje rezultate u detekciji mime vrste.",
    "System locale can not be set to a one which supports UTF-8." : "Regionalnu šemu sustava nemoguće je postaviti na neku koja podržava UTF-8.",
    "This means that there might be problems with certain characters in file names." : "To znači da se mogu javiti problemi s određenim znakovima u nazivu datoteke.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Strogo se preporučuje instaliranje zahtjevnih paketa na vašem sistemu koji podržavaju jednu od slijedećih regionalnih šemi: %s.",
    "Get the apps to sync your files" : "Koristite aplikacije za sinhronizaciju svojih datoteka",
    "Desktop client" : "Desktop klijent",
    "Android app" : "Android aplikacija",
    "iOS app" : "iOS aplikacija",
    "Show First Run Wizard again" : "Opet pokažite First Run Wizard",
    "Add" : "Dodaj",
    "Profile picture" : "Slika profila",
    "Upload new" : "Učitaj novu",
    "Remove image" : "Ukloni sliku",
    "Cancel" : "Odustani",
    "Email" : "E-pošta",
    "Your email address" : "Vaša adresa e-pošte",
    "Password" : "Lozinka",
    "Unable to change your password" : "Vašu lozinku nije moguće promijeniti",
    "Current password" : "Trenutna lozinka",
    "New password" : "Nova lozinka",
    "Change password" : "Promijeni lozinku",
    "Help translate" : "Pomozi prevesti",
    "Name" : "Ime",
    "Username" : "Korisničko ime",
    "Version" : "Verzija",
    "New Password" : "Nova Lozinka",
    "Personal" : "Osobno",
    "Admin" : "Admin",
    "Settings" : "Postavke",
    "Show storage location" : "Prikaži mjesto pohrane",
    "Show last log in" : "Prikaži zadnju prijavu",
    "Show user backend" : "Prikaži korisničku pozadinu (backend)",
    "Show email address" : "Prikaži adresu e-pošte",
    "E-Mail" : "E-pošta",
    "Admin Recovery Password" : "Admin lozinka za oporavak",
    "Enter the recovery password in order to recover the users files during password change" : "Unesite lozinku za oporavak da biste oporavili korisničke datoteke tokom promjene lozinke",
    "Add Group" : "Dodaj Grupu",
    "Group" : "Grupa",
    "Everyone" : "Svi",
    "Admins" : "Administratori",
    "Default Quota" : "Zadana kvota",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Molim unesite kvotu za spremanje (npr: \"512 MB\" ili \"12 GB\")",
    "Unlimited" : "Neograničeno",
    "Other" : "Ostali",
    "Full Name" : "Puno ime",
    "Group Admin for" : "Grupa Admin za",
    "Quota" : "Kvota",
    "Storage Location" : "Mjesto za spremanje",
    "User Backend" : "Korisnička Pozadina (Backend)",
    "Last Login" : "Zadnja prijava",
    "change full name" : "promijeni puno ime",
    "set new password" : "postavi novu lozinku",
    "change email address" : "promjeni adresu e-pošte",
    "Default" : "Zadano"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
